@@ -1,6 +1,6 @@
 from common.rest_extend.response import RESTResponse, Results, FORBID_CODE
 from django.utils.deprecation import MiddlewareMixin
-from tenant_auth.models import AuthTenant, AuthTenantRole, AuthPermission, AuthRolePermissions
+from tenant_auth.models import Tenant, TenantRole, Permission, RolePermissions
 
 IGNORE_SOURCE = ["/"]
 
@@ -25,16 +25,16 @@ class AuthMiddleware(MiddlewareMixin):
 
         method = request.method
         path = request.path
-        tenant = AuthTenant.objects.filter(account=account).first()
+        tenant = Tenant.objects.filter(account=account).first()
         if tenant:
             if tenant.account == "admin":
                 return True
             # permission = AuthPermission.objects.filter(action=method, source_id=path).first()
-            permission = AuthPermission.objects.filter(source_id=path).first()
+            permission = Permission.objects.filter(source_id=path).first()
             if permission:
-                tenant_role = AuthTenantRole.objects.filter(tenant_id=account).first()
+                tenant_role = TenantRole.objects.filter(tenant_id=account).first()
                 if tenant_role:
-                    role_permissions = AuthRolePermissions.objects.filter(
+                    role_permissions = RolePermissions.objects.filter(
                         role_id=tenant_role.role_id, permission_id=permission.name
                     ).first()
                     if role_permissions:
